@@ -3,11 +3,12 @@
 # Copyright (c) Microsoft Corporation.
 # Licensed under the MIT License.
 
-from typing import Dict, Optional
+from typing import Dict, List, Optional
 from uuid import UUID
 
 from pydantic import BaseModel
 
+from .enums import VmState
 from .models import Forward, NodeCommandEnvelope
 from .primitives import Region
 
@@ -25,6 +26,16 @@ class ProxyGetResult(BaseResponse):
     forward: Forward
 
 
+class ProxyInfo(BaseModel):
+    region: Region
+    proxy_id: UUID
+    state: VmState
+
+
+class ProxyList(BaseResponse):
+    proxies: List[ProxyInfo]
+
+
 class Version(BaseResponse):
     git: str
     build: str
@@ -38,6 +49,7 @@ class Info(BaseResponse):
     versions: Dict[str, Version]
     instance_id: Optional[UUID]
     insights_appid: Optional[str]
+    insights_instrumentation_key: Optional[str]
 
 
 class ContainerInfoBase(BaseResponse):
